==> gwisp-0.0.31.tgz: package/test/index.js <==
const assert = require('assert')
const sh = require('shelljs')
const path = require('path')
const childProcess = require('child_process')

var root = path.join(__dirname, '..')

describe('coding', function () {
  it('verfiy standard', function () {
    this.timeout(30000)
    var codingTest = [
      'node node_modules/standard/bin/cmd.js',
      '> tmp/report-coding.log'
    ].join(' ')

    assert.equal(sh.mkdir('-p', 'tmp').code, 0)
    assert.equal(sh.exec(codingTest).code, 0)
  })
})

describe('doc', function () {
  it('raml', function () {
    this.timeout(30000)

    assert.equal(sh.exec('gulp raml').code, 0)
  })

  it('manpage', function () {
    this.timeout(30000)

    assert.equal(sh.exec('gulp manpage').code, 0)
  })

  it('jsdoc', function () {
    this.timeout(30000)
    var cmd = [
      'node node_modules/.bin/jsdoc',
      '--destination man/api',
      '--configure', path.join(root, 'conf.json'),
      '-t', path.join(root, 'node_modules/ink-docstrap/template'),
      '--readme', path.join(root, 'readme.md'),
      '--recurse', path.join(root)
    ].join(' ')

    assert.equal(sh.rm('-rf', 'man/api'), 0)
    assert.equal(sh.exec(cmd).code, 0)
  })
})

describe('api', function () {
  it('verfiy api', function (done) {
    this.timeout(60000)
    var wisperdStart = path.join(__dirname, '../bin/wisper.js')
    var abaoCmd = [
      'abao design/main.raml', '--server http://localhost:9001',
      '--hookfiles abao-hook.js',
      '--reporter > tmp/report-api.log'
    ].join(' ')

    console.log('start api service. wait for it up')
    var wisperProc = childProcess.execFile('node', [wisperdStart, 'start'])

    assert.equal(sh.mkdir('-p', 'tmp'), 0)

    // wait 3 seconds for service up and start test
    setTimeout(function () {
      var verifyCode = sh.exec(abaoCmd).code

      console.log('stop api service')
      wisperProc.kill()

      assert.equal(verifyCode, 0)

      done()
    }, 3000)
  })
})

describe('package', function () {
  var pkgTimeout = 60000
  var installDir = path.join(__dirname, '../tmp/install')

  it('install', function () {
    this.timeout(pkgTimeout)
    var installCmd = [
      'npm install --prefix', installDir, root
    ].join(' ')

    assert.equal(sh.rm('-rf', installDir), 0)
    assert.equal(sh.mkdir('-p', installDir), 0)
    assert.equal(sh.exec(installCmd).code, 0)
  })

  it('remove to specify directory', function () {
    this.timeout(pkgTimeout)
    var removeCmd = [
      'npm remove --prefix', installDir, 'wisper.service'
    ].join(' ')

    assert.equal(sh.exec(removeCmd).code, 0)
  })
})

==> gwisp-0.0.33.tgz: package/test/index.js <==
const assert = require('assert')
const sh = require('shelljs')
const path = require('path')
const childProcess = require('child_process')

var root = path.join(__dirname, '..')

describe('coding', function () {
  it('verfiy standard', function () {
    this.timeout(30000)
    var codingTest = [
      'node node_modules/standard/bin/cmd.js',
      '> tmp/report-coding.log'
    ].join(' ')

    assert.equal(sh.mkdir('-p', 'tmp').code, 0)
    assert.equal(sh.exec(codingTest).code, 0)
  })
})

describe('doc', function () {
  it('raml', function () {
    this.timeout(30000)

    assert.equal(sh.exec('gulp raml').code, 0)
  })

  it('manpage', function () {
    this.timeout(30000)

    assert.equal(sh.exec('gulp manpage').code, 0)
  })

  it('jsdoc', function () {
    this.timeout(30000)
    var cmd = [
      'node node_modules/.bin/jsdoc',
      '--destination man/api',
      '--configure', path.join(root, 'conf.json'),
      // '-t', path.join(root, 'node_modules/ink-docstrap/template'),
      '--readme', path.join(root, 'readme.md'),
      '--recurse', path.join(root)
    ].join(' ')

    assert.equal(sh.rm('-rf', 'man/api'), 0)
    assert.equal(sh.exec(cmd).code, 0)
  })
})

describe('api', function () {
  it('verfiy api', function (done) {
    this.timeout(60000)
    var wisperdStart = path.join(__dirname, '../bin/wisper.js')
    var abaoCmd = [
      'abao design/main.raml', '--server http://localhost:9001',
      '--hookfiles abao-hook.js',
      '--reporter > tmp/report-api.log'
    ].join(' ')

    console.log('start api service. wait for it up')
    var wisperProc = childProcess.execFile('node', [wisperdStart, 'start'])

    assert.equal(sh.mkdir('-p', 'tmp'), 0)

    // wait 3 seconds for service up and start test
    setTimeout(function () {
      var verifyCode = sh.exec(abaoCmd).code

      console.log('stop api service')
      wisperProc.kill()

      assert.equal(verifyCode, 0)

      done()
    }, 3000)
  })
})

describe('package', function () {
  var pkgTimeout = 60000
  var installDir = path.join(__dirname, '../tmp/install')

  it('install', function () {
    this.timeout(pkgTimeout)
    var installCmd = [
      'npm install --prefix', installDir, root
    ].join(' ')

    assert.equal(sh.rm('-rf', installDir), 0)
    assert.equal(sh.mkdir('-p', installDir), 0)
    assert.equal(sh.exec(installCmd).code, 0)
  })

  it('remove to specify directory', function () {
    this.timeout(pkgTimeout)
    var removeCmd = [
      'npm remove --prefix', installDir, 'wisper.service'
    ].join(' ')

    assert.equal(sh.exec(removeCmd).code, 0)
  })
})
